<?php

namespace Drupal\entity_sanitizer\Annotation;

use Drupal\Component\Annotation\Plugin;
use Drupal\Core\Annotation\Translation;

/**
 * Defines a FieldSanitizer annotation object.
 *
 * Sanitizers handle the database sanitation of field values. They are typically
 * instantiated and invoked by the FieldSanitizerManager object.
 *
 * @Annotation
 *
 * @see \Drupal\entity_sanitizer\FieldSanitizerManager
 * @see \Drupal\entity_sanitizer\FieldSanitizerInterface
 * @see plugin_api
 *
 * @ingroup entity_sanitizer
 */
class FieldSanitizer extends Plugin {

  /**
   * The plugin ID.
   *
   * @var string
   */
  public string $id;

  /**
   * The human-readable name of the sanitizer.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public Translation $label;

  /**
   * The name of the field formatter class.
   *
   * This is not provided manually, it will be added by the discovery mechanism.
   *
   * @var string
   */
  public string $class;

}
