<?php

namespace Drupal\entity_sanitizer\Plugin\FieldSanitizer;

use Drupal\entity_sanitizer\FieldSanitizerBase;

/**
 * Handles sanitizing for the string field types.
 *
 * @package Drupal\entity_sanitizer\Plugin\FieldSanitizer
 *
 * @FieldSanitizer(
 *   id = "string",
 *   label = @Translation("Sanitizer for string type fields")
 * )
 */
class StringSanitizer extends FieldSanitizerBase {

  /**
   * {@inheritdoc}
   */
  public function getFieldValues(string $table_name, string $field_name, array $columns): array {
    if ($this->configuration['human_readable'] === TRUE) {
      $human_readable = $this->readableFieldName($field_name);
      $fields = [
        $field_name . '_value' => "CONCAT_WS(' ', '{$human_readable}', '[', {$table_name}.entity_id, ']')",
      ];
    }
    else {
      $fields = [
        $field_name . '_value' => "CONCAT_WS(' ', 'Sanitized ', {$table_name}.bundle, '{$field_name} field of type {$this->getPluginId()}', {$table_name}.entity_id, {$table_name}.revision_id, {$table_name}.langcode, {$table_name}.delta)",
      ];
    }

    // Ensure we don't break fields with a max length.
    if (!empty($columns['value']['length']) && is_numeric($columns['value']['length'])) {
      $fields[$field_name . '_value'] = 'SUBSTRING(' . $fields[$field_name . '_value'] . ', 1, ' . $columns['value']['length'] . ')';
    }

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function readableFieldName($field_name): string {

    $field_name = str_replace(['field', '_'], ' ', $field_name);

    return ucfirst(trim($field_name));
  }

}
