<?php

namespace Drupal\entity_sanitizer;

/**
 * Unsupported field type exception.
 */
class UnsupportedFieldTypeException extends \Exception {

  /**
   * The field type that caused this exception.
   *
   * @var string
   */
  private string $fieldType;

  /**
   * The field that caused this exception.
   *
   * @var string
   */
  private string $fieldName;

  /**
   * UnsupportedFieldTypeException constructor.
   *
   * @param string $field_type
   *   Field type.
   * @param string $field_name
   *   Field name.
   * @param int $code
   *   Code.
   * @param \Exception|null $previous
   *   Exception class.
   */
  public function __construct($field_type, $field_name, $code = 0, \Exception $previous = NULL) {
    $this->fieldType = $field_type;
    $this->fieldName = $field_name;
    parent::__construct("Unsupported sanitize field type {$field_type} for field {$field_name}.", $code, $previous);
  }

  /**
   * Returns field type.
   *
   * @return string
   *   The field type that caused this exception.
   */
  public function getFieldType(): string {
    return $this->fieldType;
  }

  /**
   * Returns field name.
   *
   * @return string
   *   The field that caused this exception.
   */
  public function getFieldName(): string {
    return $this->fieldName;
  }

}
